@@ -353,5 +353,16 @@ ETHEREUM_MAINNET_NETWORK_NAME: str = "Mainnet"
 ETHEREUM_BSC_MAINNET_NETWORK_NAME: str = "BSC-Mainnet"
 ETHEREUM_POLYGON_MAINNET_NETWORK_NAME: str = "Polygon-Mainnet"
 ETHEREUM_RINKEBY_NETWORK_NAME: str = "Rinkeby"
+
 ETHEREUM_MAINNET_NETWORK_NUM: int = 5
+ETHEREUM_BSC_MAINNET_NETWORK_NUM: int = 10
+ETHEREUM_POLYGON_MAINNET_NETWORK_NUM: int = 36
+ETHEREUM_RINKEBY_NETWORK_NUM: int = 29
+
+BLOCKCHAIN_NETWORK_NUM_TO_NETWORK_NAME = {
+    ETHEREUM_MAINNET_NETWORK_NUM: "Ethereum",
+    ETHEREUM_BSC_MAINNET_NETWORK_NUM: "BSC",
+    ETHEREUM_POLYGON_MAINNET_NETWORK_NUM: "Polygon"
+}
+
 ALLOWED_NETWORKS = {"Mainnet": 5}
