@@ -1,8 +1,6 @@
 import blxr_rlp as rlp
 
-from bxgateway.messages.eth.protocol.block_bodies_eth_protocol_message import \
-    BlockBodiesEthProtocolMessage
-from bxgateway.messages.eth.protocol.eth_protocol_message import EthProtocolMessage
+from bxgateway.messages.eth.protocol.block_bodies_eth_protocol_message import BlockBodiesEthProtocolMessage
 
 
 class BlockBodiesV66EthProtocolMessage(BlockBodiesEthProtocolMessage):
@@ -13,7 +11,7 @@ class BlockBodiesV66EthProtocolMessage(BlockBodiesEthProtocolMessage):
 
     def __repr__(self):
         return (
-            f"{repr(self.get_message())}<request_id: {self.get_request_id()}>"
+            f"{repr(self.get_message())[:-1]}, request_id: {self.get_request_id()}>"
         )
 
     def get_request_id(self) -> int:
