@@ -13,7 +13,7 @@ class GetReceiptsV66EthProtocolMessage(GetReceiptsEthProtocolMessage):
 
     def __repr__(self):
         return (
-            f"{repr(self.get_message())}<request_id: {self.get_request_id()}>"
+            f"<GetReceiptsEthProtocolMessage {len(self.get_block_hashes())} request_id: {self.get_request_id()}>"
         )
 
     def get_request_id(self) -> int:
